@@ -21,11 +21,11 @@
     <message>
         <location filename="../halfactory.cpp" line="52"/>
         <source>This plugin provides removable devices detection using HAL</source>
-        <translation>Dieses Modul bietet die Erkennung von Wechseldatenträgern mithilfe von HAL</translation>
+        <translation>Dieses Modul bietet die Erkennung von Wechseldatenträgern mit Hilfe von HAL</translation>
     </message>
     <message>
         <location filename="../halfactory.cpp" line="53"/>
-        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
+        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
         <translation>Autor: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
     <message>
@@ -37,14 +37,14 @@
 <context>
     <name>HalPlugin</name>
     <message>
-        <location filename="../halplugin.cpp" line="161"/>
+        <location filename="../halplugin.cpp" line="162"/>
         <source>Add CD &quot;%1&quot;</source>
         <translation>CD „%1“ hinzufügen</translation>
     </message>
     <message>
-        <location filename="../halplugin.cpp" line="167"/>
+        <location filename="../halplugin.cpp" line="168"/>
         <source>Add Volume &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation>Gerät „%1“ hinzufügen</translation>
     </message>
 </context>
 <context>
