@@ -49,8 +49,8 @@ void LyricsFactory::showAbout(QWidget *parent)
 {
     QMessageBox::about (parent, tr("About Lyrics Plugin"),
                         tr("Qmmp Lyrics Plugin")+"\n"+
-                        tr("This plugin retrieves lyrics from lyricsplugin.com")+"\n"+
-                        tr("Writen by: Ilya Kotov <forkotov02@hotmail.ru>"));
+                        tr("This plugin retrieves lyrics from LyricWiki")+"\n"+
+                        tr("Written by: Ilya Kotov <forkotov02@hotmail.ru>"));
 }
 
 QTranslator *LyricsFactory::createTranslator(QObject *parent)
