@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by Ilya Kotov                                      *
+ *   Copyright (C) 2008-2010 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -23,6 +23,8 @@
 #include <QWidget>
 #include <QFrame>
 
+#define DEFAULT_TEMPLATE "<b>%if(%t,%t,%f)</b> %if(%l,\\(%l\\),) \n%if(%p,<br>%p,)\n%if(%a,<br>%a,)"
+
 class QTimer;
 class QLabel;
 
@@ -60,8 +62,10 @@ private:
     void updatePosition();
     QTimer *m_timer;
     QLabel *m_label1;
-    QLabel *m_label2;
+    QLabel *m_pixlabel;
+    QString m_template;
     uint m_pos;
+    int m_coverSize;
 
 };
 
