@@ -20,7 +20,7 @@
     </message>
     <message>
         <location filename="../scrobblerfactory.cpp" line="52"/>
-        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
+        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
         <translation>Розробник: Ілля Котов  &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
 </context>
@@ -38,18 +38,26 @@
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="41"/>
-        <location filename="../settingsdialog.ui" line="77"/>
+        <source>Session:</source>
+        <translation>Сесія:</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="51"/>
+        <source>Register new session</source>
+        <translation>Зареєструвати нову сесію</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="70"/>
         <source>User name:</source>
         <translation>Ім&apos;я користувача:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="51"/>
-        <location filename="../settingsdialog.ui" line="87"/>
+        <location filename="../settingsdialog.ui" line="80"/>
         <source>Password:</source>
         <translation>Пароль:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="68"/>
+        <location filename="../settingsdialog.ui" line="61"/>
         <source>Libre.fm</source>
         <translation>Libre.fm</translation>
     </message>
