@@ -39,10 +39,15 @@
         <source>0</source>
         <translation>0</translation>
     </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="225"/>
+        <source>Edit template</source>
+        <translation>Vorlage bearbeiten</translation>
+    </message>
     <message>
         <location filename="../settingsdialog.ui" line="91"/>
         <source>Try to split file name when no tag</source>
-        <translation type="unfinished">Versuchen Dateinamen zu trennen, wenn kein Tag vorhanden</translation>
+        <translation>Versuchen Dateinamen zu trennen, wenn kein Tag vorhanden</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="174"/>
@@ -54,11 +59,6 @@
         <source>32</source>
         <translation>32</translation>
     </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="225"/>
-        <source>Change template</source>
-        <translation>Vorlage ändern</translation>
-    </message>
     <message>
         <location filename="../settingsdialog.ui" line="250"/>
         <source>Use standard icons</source>
@@ -122,7 +122,7 @@
     </message>
     <message>
         <location filename="../statusiconfactory.cpp" line="52"/>
-        <source>Writen by:</source>
+        <source>Written by:</source>
         <translation>Autor:</translation>
     </message>
     <message>
