@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by Ilya Kotov                                      *
+ *   Copyright (C) 2008-2012 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -42,13 +42,14 @@ class QBuffer;
 class AACFile
 {
 public:
-    AACFile(QIODevice *i, bool metaData = true);
+    AACFile(QIODevice *i, bool metaData = true, bool adts = true);
 
     ~AACFile();
 
     qint64 length();
     quint32 bitrate();
     quint32 samplerate();
+    int offset() const;
     bool isValid();
     const QMap<Qmmp::MetaData, QString> metaData();
 
@@ -57,6 +58,7 @@ private:
     void parseID3v2();
     qint64 m_length;
     quint32 m_bitrate;
+    int m_offset;
     QIODevice *m_input;
     bool m_isValid;
     quint32 m_samplerate;
