@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2011 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2012 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -20,6 +20,57 @@
 
 #include "ffmpegmetadatamodel.h"
 
+#if (LIBAVCODEC_VERSION_INT >= ((53<<16)+(42<<8)+4))
+
+FFmpegMetaDataModel::FFmpegMetaDataModel(const QString &path, QObject *parent) : MetaDataModel(parent)
+{
+    m_in = 0;
+    avcodec_register_all();
+    avformat_network_init();
+    av_register_all();
+
+
+    if (avformat_open_input(&m_in, path.toLocal8Bit().constData(), 0, 0) < 0)
+        return;
+    avformat_find_stream_info(m_in, 0);
+    av_read_play(m_in);
+}
+
+FFmpegMetaDataModel::~FFmpegMetaDataModel()
+{
+    if(m_in)
+        avformat_close_input(&m_in);
+}
+
+QHash<QString, QString> FFmpegMetaDataModel::audioProperties()
+{
+    QHash<QString, QString> ap;
+    if(!m_in)
+        return ap;
+    QString text = QString("%1").arg(int(m_in->duration/AV_TIME_BASE)/60);
+    text +=":"+QString("%1").arg(int(m_in->duration/AV_TIME_BASE)%60,2,10,QChar('0'));
+    ap.insert(tr("Length"), text);
+    ap.insert(tr("File size"),  QString("%1 ").arg(avio_size(m_in->pb)) + " " + tr("KB"));
+    ap.insert(tr("Bitrate"), QString("%1 "+tr("kbps")).arg(m_in->bit_rate/1000));
+
+    AVCodecContext *c = 0;
+    uint wma_idx;
+    for (wma_idx = 0; wma_idx < m_in->nb_streams; wma_idx++)
+    {
+        c = m_in->streams[wma_idx]->codec;
+        if (c->codec_type == AVMEDIA_TYPE_AUDIO)
+            break;
+    }
+    if (c)
+    {
+        ap.insert(tr("Sample rate"), QString("%1 " + tr("Hz")).arg(c->sample_rate));
+        ap.insert(tr("Channels"), QString("%1").arg(c->channels));
+    }
+    return ap;
+}
+
+#else
+
 FFmpegMetaDataModel::FFmpegMetaDataModel(const QString &path, QObject *parent) : MetaDataModel(parent)
 {
     m_in = 0;
@@ -68,3 +119,5 @@ QHash<QString, QString> FFmpegMetaDataModel::audioProperties()
     }
     return ap;
 }
+
+#endif
