@@ -86,9 +86,9 @@ const DecoderProperties DecoderMADFactory::properties() const
     DecoderProperties properties;
     properties.name = tr("MPEG Plugin");
     properties.shortName = "mad";
-    properties.filter = "*.mp1 *.mp2 *.mp3 *.wav";
+    properties.filters << "*.mp1" << "*.mp2" << "*.mp3" << "*.wav";
     properties.description = tr("MPEG Files");
-    properties.contentType = "audio/mp3;audio/mpeg";
+    properties.contentTypes << "audio/mp3" << "audio/mpeg";
     properties.hasAbout = true;
     properties.hasSettings = true;
     return properties;
@@ -223,7 +223,7 @@ void DecoderMADFactory::showAbout(QWidget *parent)
                         QString("%1.%2.%3%4").arg(MAD_VERSION_MAJOR)
                         .arg(MAD_VERSION_MINOR)
                         .arg(MAD_VERSION_PATCH).arg(MAD_VERSION_EXTRA)+"\n"+
-                        tr("Writen by: Ilya Kotov <forkotov02@hotmail.ru>")+"\n"+
+                        tr("Written by: Ilya Kotov <forkotov02@hotmail.ru>")+"\n"+
                         tr("Source code based on mq3 progect")
                        );
 }
