@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2011 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2012 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -184,7 +184,7 @@ void MMSStreamReader::run()
         m_mutex.unlock();
         if(m_aborted)
             break;
-        usleep(5000);
+        DownloadThread::usleep(5000);
     }
 }
 
