@@ -49,7 +49,7 @@ void VisualProjectMFactory::showAbout(QWidget *parent)
     QMessageBox::about (parent, tr("About ProjectM Visual Plugin"),
                         tr("Qmmp ProjectM Visual Plugin")+"\n"+
                         tr("This plugin adds projectM visualization")+"\n"+
-                        tr("Writen by: Ilya Kotov <forkotov02@hotmail.ru>")+"\n"+
+                        tr("Written by: Ilya Kotov <forkotov02@hotmail.ru>")+"\n"+
                         tr("Based on llibrojectM-qt library"));
 }
 
