@@ -21,6 +21,7 @@
 #include <QStringList>
 #include <QDir>
 #include <QApplication>
+#include <QHash>
 #include "qmmpaudioengine.h"
 #include "qmmp.h"
 #include "effectfactory.h"
@@ -59,7 +60,7 @@ Qmmp::AudioFormat Effect::format()
     return m_format;
 }
 
-const AudioParameters  Effect::audioParameters() const
+const AudioParameters Effect::audioParameters() const
 {
     return AudioParameters(m_freq, m_chan, m_format);
 }
@@ -69,9 +70,9 @@ EffectFactory* Effect::factory() const
     return m_factory;
 }
 
-void Effect::setFactory(EffectFactory *factory)
+bool effectCompareFunc(EffectFactory *e1, EffectFactory *e2)
 {
-    m_factory = factory;
+    return e1->properties().priority > e2->properties().priority;
 }
 
 //static members
@@ -88,6 +89,7 @@ void Effect::checkFactories()
 
         QDir pluginsDir (Qmmp::pluginsPath());
         pluginsDir.cd("Effect");
+        QHash <EffectFactory*, QString> m_hash;
         foreach (QString fileName, pluginsDir.entryList(QDir::Files))
         {
             QPluginLoader loader(pluginsDir.absoluteFilePath(fileName));
@@ -104,27 +106,24 @@ void Effect::checkFactories()
             if (factory)
             {
                 m_factories->append(factory);
-                m_files << pluginsDir.absoluteFilePath(fileName);
+                m_hash.insert(factory, pluginsDir.absoluteFilePath(fileName));
                 qApp->installTranslator(factory->createTranslator(qApp));
             }
         }
+        qSort(m_factories->begin(), m_factories->end(), effectCompareFunc);
+        foreach(EffectFactory *factory, *m_factories) //generate files list with same order
+        {
+            m_files << m_hash.value(factory);
+        }
     }
 }
 
-QList<Effect*> Effect::create()
+Effect* Effect::create(EffectFactory *factory)
 {
     checkFactories();
-    QList<Effect*> effects;
-    EffectFactory *factory = 0;
-    foreach (factory, *m_factories)
-    {
-        if(isEnabled(factory))
-        {
-            effects.append(factory->create());
-            effects.last()->m_factory = factory;
-        }
-    }
-    return effects;
+    Effect *effect = factory->create();
+    effect->m_factory = factory;
+    return effect;
 }
 
 QList<EffectFactory*> *Effect::factories()
