@@ -23,6 +23,8 @@
 class QObject;
 class QTranslator;
 class QDialog;
+class QString;
+class QWidget;
 class Control;
 class General;
 
@@ -36,9 +38,9 @@ public:
      */
     GeneralProperties()
     {
-        hasAbout = FALSE;
-        hasSettings = FALSE;
-        visibilityControl = FALSE;
+        hasAbout = false;
+        hasSettings = false;
+        visibilityControl = false;
     }
     QString name;           /*!< File dialog plugin full name */
     QString shortName;      /*!< File dialog short name for internal usage */
