@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2011 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2012 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -185,7 +185,7 @@ void MediaPlayer::updateNextUrl()
         bool ok = m_core->play(item->url(), true);
         if(ok)
         {
-            m_nextUrl = m_pl_manager->currentPlayList()->nextItem()->url();
+            m_nextUrl = item->url();
             qDebug("MediaPlayer: next track state: received");
         }
         else
