@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright(C) 2006-2011 by Ilya Kotov                                  *
+ *   Copyright(C) 2006-2012 by Ilya Kotov                                  *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -650,7 +650,7 @@ static bool _albumGreaterComparator(PlayListItem* s1,PlayListItem* s2)
 //by artist
 static bool _artistLessComparator(PlayListItem* s1,PlayListItem* s2)
 {
-    return QString::localeAwareCompare (s1->value(Qmmp::ALBUM), s2->value(Qmmp::ALBUM)) < 0;
+    return QString::localeAwareCompare (s1->value(Qmmp::ARTIST), s2->value(Qmmp::ARTIST)) < 0;
 }
 
 static bool _artistGreaterComparator(PlayListItem* s1,PlayListItem* s2)
@@ -753,12 +753,12 @@ void PlayListModel::doSort(int sort_mode,QList<PlayListItem*>& list_to_sort)
     static bool sorted_asc = false;
     if (!sorted_asc)
     {
-        qSort(begin,end,compareLessFunc);
+        qStableSort(begin,end,compareLessFunc);
         sorted_asc = true;
     }
     else
     {
-        qSort(begin,end,compareGreaterFunc);
+        qStableSort(begin,end,compareGreaterFunc);
         sorted_asc = false;
     }
 
@@ -816,7 +816,7 @@ void PlayListModel::loadPlaylist(const QString &f_name)
     PlaylistFormat* prs = PlaylistParser::instance()->findByPath(f_name);
     if(!prs)
     {
-        qWarning("PlayListModel: unsupported playlist format");
+        //qWarning("PlayListModel: unsupported playlist format");
         return;
     }
 
@@ -903,10 +903,12 @@ void PlayListModel::removeDuplicates()
 {
     for(int i = 0; i < m_items.size(); ++i)
     {
-        for(int j = i + 1; j < m_items.size(); ++j)
+        int j = m_items.size() - 1;
+        while(j > i)
         {
             if(m_items.at(i)->url() == m_items.at(j)->url())
                 removeItem(m_items.at(j));
+            j--;
         }
     }
 }
