@@ -29,7 +29,7 @@
 #include <QLibraryInfo>
 #include <stdio.h>
 #include <stdlib.h>
-
+#include "lxdesupport.h"
 #include "mainwindow.h"
 #include "playlist.h"
 #include "qmmpstarter.h"
@@ -38,6 +38,9 @@ int main(int argc, char *argv[])
 {
     QApplication a (argc, argv );
     a.setApplicationName("qmmp");
+
+    LXDESupport::load(); //load lxde icons
+
     QTranslator translator;
     QString locale = Qmmp::systemLanguageID();
     translator.load(QString(":/qmmp_") + locale);
