@@ -32,9 +32,9 @@ ToggleButton::ToggleButton ( QWidget *parent,uint on_n,uint on_p,uint off_n,uint
    m_on_p = on_p;
    m_off_n = off_n;
    m_off_p = off_p;
-   m_on = FALSE;
-   skin = Skin::getPointer();
-   setON ( FALSE );
+   m_on = false;
+   skin = Skin::instance();
+   setON ( false );
    connect ( skin, SIGNAL ( skinChanged() ), this, SLOT ( updateSkin() ) );
 }
 
@@ -70,7 +70,7 @@ void ToggleButton::setON ( bool on )
 }
 void ToggleButton::mousePressEvent ( QMouseEvent* )
 {
-   m_cursorin = TRUE;
+   m_cursorin = true;
    m_old_on = m_on;
    if ( m_on )
       setPixmap ( skin->getButton ( m_off_p ) );
@@ -93,13 +93,13 @@ void ToggleButton::mouseReleaseEvent ( QMouseEvent* )
 void ToggleButton::mouseMoveEvent (QMouseEvent *e)
 {
     if ( !m_cursorin && rect().contains(e->pos()) ) {
-        m_cursorin = TRUE;
+        m_cursorin = true;
         if ( m_old_on )
             setPixmap ( skin->getButton ( m_off_p ) );
         else
             setPixmap ( skin->getButton ( m_on_p ) );            
     } else if ( m_cursorin && !rect().contains(e->pos()) ) {
-        m_cursorin = FALSE;
+        m_cursorin = false;
         if ( m_old_on )
             setPixmap ( skin->getButton ( m_on_n ) );
         else
